==> geopsypack-src-3.3.5.tar.gz: geopsypack-src-3.3.5/QGpGuiTools/src/Attachments.h <==
/***************************************************************************
**
**  This file is part of QGpGuiTools.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2007-01-05
**  Copyright: 2007-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef ATTACHMENTS_H
#define ATTACHMENTS_H

#include <QtGui>

#include "Dialog.h"
#include "ui_Attachments.h"

namespace QGpGuiTools {

class Attachments : public Dialog, public Ui::Attachments
{
    Q_OBJECT
public:
  Attachments(QWidget* parent=nullptr, Qt::WindowFlags fl=nullptr);
  ~Attachments();

  QStringList getFileList();
public slots:
  void setFileList(QStringList files);
  void on_addFile_clicked();
  void on_removeFile_clicked();
};

} // namespace QGpGuiTools

#endif // ATTACHMENTS_H

==> geopsypack-src-3.5.1.tar.gz: geopsypack-src-3.5.1/QGpGuiTools/src/Attachments.h <==
/***************************************************************************
**
**  This file is part of QGpGuiTools.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2007-01-05
**  Copyright: 2007-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef ATTACHMENTS_H
#define ATTACHMENTS_H

#include <QtGui>

#include "Dialog.h"
#include "ui_Attachments.h"

namespace QGpGuiTools {

class Attachments : public Dialog, public Ui::Attachments
{
    Q_OBJECT
public:
  Attachments(QWidget* parent=nullptr, Qt::WindowFlags fl=Qt::WindowFlags());
  ~Attachments();

  QStringList getFileList();
public slots:
  void setFileList(QStringList files);
  void on_addFile_clicked();
  void on_removeFile_clicked();
};

} // namespace QGpGuiTools

#endif // ATTACHMENTS_H
